==> haskell-monad-logger-0.3.42-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-8qb2rjVodGvEUwPFGSvRJj
key:                  monad-logger-0.3.42-8qb2rjVodGvEUwPFGSvRJj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  9dba5cd2ea8f2f780adc76872c66e1c9
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-8qb2rjVodGvEUwPFGSvRJj
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-EEoD2QArhRxFbtxrlaKgkd
    conduit-extra-1.3.8-4vGcjD1RnCr9zclEb4aEgy exceptions-0.10.5
    fast-logger-3.2.3-DeT2TRpuu17FRRtRFZyjKS
    lifted-base-0.2.3.12-8jv2OI8JOeaE6wsyLlY7lV
    monad-control-1.0.3.1-1muznQSV14KveEnsCnoJt
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    resourcet-1.2.6-9JXf0ifNhclLJYQG5fNMEA stm-2.5.1.0
    stm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-4sFiAxABgpA4ZaU1ZWKFkZ
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.42-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-3EJ00GIPOmWLmCF8CIXrJ9
key:                  monad-logger-0.3.42-3EJ00GIPOmWLmCF8CIXrJ9
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  173fc2c8b38963a0f6789ab1a8fb9287
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-3EJ00GIPOmWLmCF8CIXrJ9
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-2lml8TYLrSoCJWeVqTIcf8
    conduit-extra-1.3.8-FOWZ5xxlIhQAwh6RwRPJbV exceptions-0.10.5
    fast-logger-3.2.3-DeT2TRpuu17FRRtRFZyjKS
    lifted-base-0.2.3.12-8jv2OI8JOeaE6wsyLlY7lV
    monad-control-1.0.3.1-1muznQSV14KveEnsCnoJt
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    resourcet-1.2.6-9JXf0ifNhclLJYQG5fNMEA stm-2.5.1.0
    stm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-4sFiAxABgpA4ZaU1ZWKFkZ
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
